Crate into_static

Upgrading to static lifetimes.

This crate provides the IntoStatic trait, which allows upgrading all lifetimes to 'static.

IntoStatic is implemented for Option<T> and Result<T, E>, provided T and E are also IntoStatic.

The trait is also implemented for arrays [T; N] and tuples containing to 12 items, provided each type is IntoStatic.

When the std or alloc feature is enabled, IntoStatic is also implemented for Cow<'_, T>, yielding Cow<'static, T> (provided T: 'static is satisfied).

Traits

IntoStatic
Upgrading to 'static lifetimes.