Trait IntoStatic

pub trait IntoStatic {
    type Static: IntoStatic<Static = Self::Static> + 'static;

    // Required method
    fn into_static(self) -> Self::Static;
}
Upgrading to 'static lifetimes.

Required Associated Types

type Static: IntoStatic<Static = Self::Static> + 'static

The type with 'static lifetimes.

Required Methods

fn into_static(self) -> Self::Static

Upgrades Self to Self::Static.

Implementations on Foreign Types

Source

impl IntoStatic for Cow<'_, str>

Available on crate features std or alloc only.
Source

type Static = Cow<'static, str>

Source

fn into_static(self) -> Self::Static

Source

impl<A: IntoStatic> IntoStatic for (A,)

Source

type Static = (<A as IntoStatic>::Static,)

Source

fn into_static(self) -> Self::Static

Source

impl<A: IntoStatic, B: IntoStatic> IntoStatic for (A, B)

Source

type Static = (<A as IntoStatic>::Static, <B as IntoStatic>::Static)

Source

fn into_static(self) -> Self::Static

Source

impl<A: IntoStatic, B: IntoStatic, C: IntoStatic> IntoStatic for (A, B, C)

Source

type Static = (<A as IntoStatic>::Static, <B as IntoStatic>::Static, <C as IntoStatic>::Static)

Source

fn into_static(self) -> Self::Static

Source

impl<A: IntoStatic, B: IntoStatic, C: IntoStatic, D: IntoStatic> IntoStatic for (A, B, C, D)

Source

type Static = (<A as IntoStatic>::Static, <B as IntoStatic>::Static, <C as IntoStatic>::Static, <D as IntoStatic>::Static)

Source

fn into_static(self) -> Self::Static

Source

impl<A: IntoStatic, B: IntoStatic, C: IntoStatic, D: IntoStatic, E: IntoStatic> IntoStatic for (A, B, C, D, E)

Source

type Static = (<A as IntoStatic>::Static, <B as IntoStatic>::Static, <C as IntoStatic>::Static, <D as IntoStatic>::Static, <E as IntoStatic>::Static)

Source

fn into_static(self) -> Self::Static

Source

impl<A: IntoStatic, B: IntoStatic, C: IntoStatic, D: IntoStatic, E: IntoStatic, F: IntoStatic> IntoStatic for (A, B, C, D, E, F)

Source

type Static = (<A as IntoStatic>::Static, <B as IntoStatic>::Static, <C as IntoStatic>::Static, <D as IntoStatic>::Static, <E as IntoStatic>::Static, <F as IntoStatic>::Static)

Source

fn into_static(self) -> Self::Static

Source

impl<A: IntoStatic, B: IntoStatic, C: IntoStatic, D: IntoStatic, E: IntoStatic, F: IntoStatic, G: IntoStatic> IntoStatic for (A, B, C, D, E, F, G)

Source

type Static = (<A as IntoStatic>::Static, <B as IntoStatic>::Static, <C as IntoStatic>::Static, <D as IntoStatic>::Static, <E as IntoStatic>::Static, <F as IntoStatic>::Static, <G as IntoStatic>::Static)

Source

fn into_static(self) -> Self::Static

Source

impl<A: IntoStatic, B: IntoStatic, C: IntoStatic, D: IntoStatic, E: IntoStatic, F: IntoStatic, G: IntoStatic, H: IntoStatic> IntoStatic for (A, B, C, D, E, F, G, H)

Source

type Static = (<A as IntoStatic>::Static, <B as IntoStatic>::Static, <C as IntoStatic>::Static, <D as IntoStatic>::Static, <E as IntoStatic>::Static, <F as IntoStatic>::Static, <G as IntoStatic>::Static, <H as IntoStatic>::Static)

Source

fn into_static(self) -> Self::Static

Source

impl<A: IntoStatic, B: IntoStatic, C: IntoStatic, D: IntoStatic, E: IntoStatic, F: IntoStatic, G: IntoStatic, H: IntoStatic, I: IntoStatic> IntoStatic for (A, B, C, D, E, F, G, H, I)

Source

type Static = (<A as IntoStatic>::Static, <B as IntoStatic>::Static, <C as IntoStatic>::Static, <D as IntoStatic>::Static, <E as IntoStatic>::Static, <F as IntoStatic>::Static, <G as IntoStatic>::Static, <H as IntoStatic>::Static, <I as IntoStatic>::Static)

Source

fn into_static(self) -> Self::Static

Source

impl<A: IntoStatic, B: IntoStatic, C: IntoStatic, D: IntoStatic, E: IntoStatic, F: IntoStatic, G: IntoStatic, H: IntoStatic, I: IntoStatic, J: IntoStatic> IntoStatic for (A, B, C, D, E, F, G, H, I, J)

Source

type Static = (<A as IntoStatic>::Static, <B as IntoStatic>::Static, <C as IntoStatic>::Static, <D as IntoStatic>::Static, <E as IntoStatic>::Static, <F as IntoStatic>::Static, <G as IntoStatic>::Static, <H as IntoStatic>::Static, <I as IntoStatic>::Static, <J as IntoStatic>::Static)

Source

fn into_static(self) -> Self::Static

Source

impl<A: IntoStatic, B: IntoStatic, C: IntoStatic, D: IntoStatic, E: IntoStatic, F: IntoStatic, G: IntoStatic, H: IntoStatic, I: IntoStatic, J: IntoStatic, K: IntoStatic> IntoStatic for (A, B, C, D, E, F, G, H, I, J, K)

Source

type Static = (<A as IntoStatic>::Static, <B as IntoStatic>::Static, <C as IntoStatic>::Static, <D as IntoStatic>::Static, <E as IntoStatic>::Static, <F as IntoStatic>::Static, <G as IntoStatic>::Static, <H as IntoStatic>::Static, <I as IntoStatic>::Static, <J as IntoStatic>::Static, <K as IntoStatic>::Static)

Source

fn into_static(self) -> Self::Static

Source

impl<A: IntoStatic, B: IntoStatic, C: IntoStatic, D: IntoStatic, E: IntoStatic, F: IntoStatic, G: IntoStatic, H: IntoStatic, I: IntoStatic, J: IntoStatic, K: IntoStatic, L: IntoStatic> IntoStatic for (A, B, C, D, E, F, G, H, I, J, K, L)

Source

type Static = (<A as IntoStatic>::Static, <B as IntoStatic>::Static, <C as IntoStatic>::Static, <D as IntoStatic>::Static, <E as IntoStatic>::Static, <F as IntoStatic>::Static, <G as IntoStatic>::Static, <H as IntoStatic>::Static, <I as IntoStatic>::Static, <J as IntoStatic>::Static, <K as IntoStatic>::Static, <L as IntoStatic>::Static)

Source

fn into_static(self) -> Self::Static

Source

impl<T: Clone + IntoStatic<Static: Clone>> IntoStatic for Cow<'_, [T]>

Available on crate features std or alloc only.
Source

type Static = Cow<'static, [<T as IntoStatic>::Static]>

Source

fn into_static(self) -> Self::Static

Source

impl<T: IntoStatic> IntoStatic for Option<T>

Source

impl<T: IntoStatic> IntoStatic for Vec<T>

Available on crate features alloc or std only.
Source

impl<T: IntoStatic, E: IntoStatic> IntoStatic for Result<T, E>

Source

impl<T: IntoStatic, const N: usize> IntoStatic for [T; N]

Source

type Static = [<T as IntoStatic>::Static; N]

Source

fn into_static(self) -> Self::Static

Implementors