Upgrading to static lifetimes.
This crate provides the IntoStatic trait, which allows upgrading all lifetimes to 'static.
IntoStatic is implemented for Option<T> and Result<T, E>, provided
T and E are also IntoStatic.
When the std or alloc feature is enabled, IntoStatic is also
implemented for Cow<'_, T>, yielding Cow<'static, T> (provided T: 'static is satisfied).
Traits
- Into
Static - Upgrading to
'staticlifetimes.