pub trait IntoStatic {
type Static: IntoStatic<Static = Self::Static> + 'static;
// Required method
fn into_static(self) -> Self::Static;
}Expand description
Upgrading to 'static lifetimes.
Required Associated Types
Sourcetype Static: IntoStatic<Static = Self::Static> + 'static
type Static: IntoStatic<Static = Self::Static> + 'static
The type with 'static lifetimes.
Required Methods
Sourcefn into_static(self) -> Self::Static
fn into_static(self) -> Self::Static
Upgrades Self to Self::Static.
Implementations on Foreign Types
Sourceimpl<A: IntoStatic> IntoStatic for (A,)
impl<A: IntoStatic> IntoStatic for (A,)
type Static = (<A as IntoStatic>::Static,)
fn into_static(self) -> Self::Static
Sourceimpl<A: IntoStatic, B: IntoStatic> IntoStatic for (A, B)
impl<A: IntoStatic, B: IntoStatic> IntoStatic for (A, B)
type Static = (<A as IntoStatic>::Static, <B as IntoStatic>::Static)
fn into_static(self) -> Self::Static
Sourceimpl<A: IntoStatic, B: IntoStatic, C: IntoStatic> IntoStatic for (A, B, C)
impl<A: IntoStatic, B: IntoStatic, C: IntoStatic> IntoStatic for (A, B, C)
type Static = (<A as IntoStatic>::Static, <B as IntoStatic>::Static, <C as IntoStatic>::Static)
fn into_static(self) -> Self::Static
Sourceimpl<A: IntoStatic, B: IntoStatic, C: IntoStatic, D: IntoStatic> IntoStatic for (A, B, C, D)
impl<A: IntoStatic, B: IntoStatic, C: IntoStatic, D: IntoStatic> IntoStatic for (A, B, C, D)
type Static = (<A as IntoStatic>::Static, <B as IntoStatic>::Static, <C as IntoStatic>::Static, <D as IntoStatic>::Static)
fn into_static(self) -> Self::Static
Sourceimpl<A: IntoStatic, B: IntoStatic, C: IntoStatic, D: IntoStatic, E: IntoStatic> IntoStatic for (A, B, C, D, E)
impl<A: IntoStatic, B: IntoStatic, C: IntoStatic, D: IntoStatic, E: IntoStatic> IntoStatic for (A, B, C, D, E)
type Static = (<A as IntoStatic>::Static, <B as IntoStatic>::Static, <C as IntoStatic>::Static, <D as IntoStatic>::Static, <E as IntoStatic>::Static)
fn into_static(self) -> Self::Static
Sourceimpl<A: IntoStatic, B: IntoStatic, C: IntoStatic, D: IntoStatic, E: IntoStatic, F: IntoStatic> IntoStatic for (A, B, C, D, E, F)
impl<A: IntoStatic, B: IntoStatic, C: IntoStatic, D: IntoStatic, E: IntoStatic, F: IntoStatic> IntoStatic for (A, B, C, D, E, F)
type Static = (<A as IntoStatic>::Static, <B as IntoStatic>::Static, <C as IntoStatic>::Static, <D as IntoStatic>::Static, <E as IntoStatic>::Static, <F as IntoStatic>::Static)
fn into_static(self) -> Self::Static
Sourceimpl<A: IntoStatic, B: IntoStatic, C: IntoStatic, D: IntoStatic, E: IntoStatic, F: IntoStatic, G: IntoStatic> IntoStatic for (A, B, C, D, E, F, G)
impl<A: IntoStatic, B: IntoStatic, C: IntoStatic, D: IntoStatic, E: IntoStatic, F: IntoStatic, G: IntoStatic> IntoStatic for (A, B, C, D, E, F, G)
type Static = (<A as IntoStatic>::Static, <B as IntoStatic>::Static, <C as IntoStatic>::Static, <D as IntoStatic>::Static, <E as IntoStatic>::Static, <F as IntoStatic>::Static, <G as IntoStatic>::Static)
fn into_static(self) -> Self::Static
Sourceimpl<A: IntoStatic, B: IntoStatic, C: IntoStatic, D: IntoStatic, E: IntoStatic, F: IntoStatic, G: IntoStatic, H: IntoStatic> IntoStatic for (A, B, C, D, E, F, G, H)
impl<A: IntoStatic, B: IntoStatic, C: IntoStatic, D: IntoStatic, E: IntoStatic, F: IntoStatic, G: IntoStatic, H: IntoStatic> IntoStatic for (A, B, C, D, E, F, G, H)
type Static = (<A as IntoStatic>::Static, <B as IntoStatic>::Static, <C as IntoStatic>::Static, <D as IntoStatic>::Static, <E as IntoStatic>::Static, <F as IntoStatic>::Static, <G as IntoStatic>::Static, <H as IntoStatic>::Static)
fn into_static(self) -> Self::Static
Sourceimpl<A: IntoStatic, B: IntoStatic, C: IntoStatic, D: IntoStatic, E: IntoStatic, F: IntoStatic, G: IntoStatic, H: IntoStatic, I: IntoStatic> IntoStatic for (A, B, C, D, E, F, G, H, I)
impl<A: IntoStatic, B: IntoStatic, C: IntoStatic, D: IntoStatic, E: IntoStatic, F: IntoStatic, G: IntoStatic, H: IntoStatic, I: IntoStatic> IntoStatic for (A, B, C, D, E, F, G, H, I)
type Static = (<A as IntoStatic>::Static, <B as IntoStatic>::Static, <C as IntoStatic>::Static, <D as IntoStatic>::Static, <E as IntoStatic>::Static, <F as IntoStatic>::Static, <G as IntoStatic>::Static, <H as IntoStatic>::Static, <I as IntoStatic>::Static)
fn into_static(self) -> Self::Static
Sourceimpl<A: IntoStatic, B: IntoStatic, C: IntoStatic, D: IntoStatic, E: IntoStatic, F: IntoStatic, G: IntoStatic, H: IntoStatic, I: IntoStatic, J: IntoStatic> IntoStatic for (A, B, C, D, E, F, G, H, I, J)
impl<A: IntoStatic, B: IntoStatic, C: IntoStatic, D: IntoStatic, E: IntoStatic, F: IntoStatic, G: IntoStatic, H: IntoStatic, I: IntoStatic, J: IntoStatic> IntoStatic for (A, B, C, D, E, F, G, H, I, J)
type Static = (<A as IntoStatic>::Static, <B as IntoStatic>::Static, <C as IntoStatic>::Static, <D as IntoStatic>::Static, <E as IntoStatic>::Static, <F as IntoStatic>::Static, <G as IntoStatic>::Static, <H as IntoStatic>::Static, <I as IntoStatic>::Static, <J as IntoStatic>::Static)
fn into_static(self) -> Self::Static
Sourceimpl<A: IntoStatic, B: IntoStatic, C: IntoStatic, D: IntoStatic, E: IntoStatic, F: IntoStatic, G: IntoStatic, H: IntoStatic, I: IntoStatic, J: IntoStatic, K: IntoStatic> IntoStatic for (A, B, C, D, E, F, G, H, I, J, K)
impl<A: IntoStatic, B: IntoStatic, C: IntoStatic, D: IntoStatic, E: IntoStatic, F: IntoStatic, G: IntoStatic, H: IntoStatic, I: IntoStatic, J: IntoStatic, K: IntoStatic> IntoStatic for (A, B, C, D, E, F, G, H, I, J, K)
type Static = (<A as IntoStatic>::Static, <B as IntoStatic>::Static, <C as IntoStatic>::Static, <D as IntoStatic>::Static, <E as IntoStatic>::Static, <F as IntoStatic>::Static, <G as IntoStatic>::Static, <H as IntoStatic>::Static, <I as IntoStatic>::Static, <J as IntoStatic>::Static, <K as IntoStatic>::Static)
fn into_static(self) -> Self::Static
Sourceimpl<A: IntoStatic, B: IntoStatic, C: IntoStatic, D: IntoStatic, E: IntoStatic, F: IntoStatic, G: IntoStatic, H: IntoStatic, I: IntoStatic, J: IntoStatic, K: IntoStatic, L: IntoStatic> IntoStatic for (A, B, C, D, E, F, G, H, I, J, K, L)
impl<A: IntoStatic, B: IntoStatic, C: IntoStatic, D: IntoStatic, E: IntoStatic, F: IntoStatic, G: IntoStatic, H: IntoStatic, I: IntoStatic, J: IntoStatic, K: IntoStatic, L: IntoStatic> IntoStatic for (A, B, C, D, E, F, G, H, I, J, K, L)
type Static = (<A as IntoStatic>::Static, <B as IntoStatic>::Static, <C as IntoStatic>::Static, <D as IntoStatic>::Static, <E as IntoStatic>::Static, <F as IntoStatic>::Static, <G as IntoStatic>::Static, <H as IntoStatic>::Static, <I as IntoStatic>::Static, <J as IntoStatic>::Static, <K as IntoStatic>::Static, <L as IntoStatic>::Static)
fn into_static(self) -> Self::Static
Sourceimpl<T: ToOwned + ?Sized + 'static> IntoStatic for Cow<'_, T>
Available on crate features std or alloc only.
impl<T: ToOwned + ?Sized + 'static> IntoStatic for Cow<'_, T>
Available on crate features
std or alloc only.Sourceimpl<T: IntoStatic> IntoStatic for Option<T>
impl<T: IntoStatic> IntoStatic for Option<T>
type Static = Option<<T as IntoStatic>::Static>
fn into_static(self) -> Self::Static
Sourceimpl<T: IntoStatic> IntoStatic for Vec<T>
Available on crate features alloc or std only.
impl<T: IntoStatic> IntoStatic for Vec<T>
Available on crate features
alloc or std only.